.. include:: /_includes/wip_prolog.rst

:mod:`stix.common.datetimewithprecision` Module
===============================================

.. module:: stix.common.datetimewithprecision

Classes
-------

.. autoclass:: DateTimeWithPrecision
	:show-inheritance:
	:members:

Constants
---------

.. autodata:: DATE_PRECISION_VALUES

.. autodata:: TIME_PRECISION_VALUES

.. autodata:: DATETIME_PRECISION_VALUES
